/// <reference types="react" />
import './index.scss';
type ProcessType = 'shadow' | 'ellipsis';
interface TextProcessProps {
    /** >>>>>>公共配置 */
    text: string;
    type?: ProcessType;
    className?: string;
    style?: React.CSSProperties;
    buttonClassName?: string;
    buttonStyle?: React.CSSProperties;
    onClick?: (() => void) | null;
    isClickOriginalEvent?: boolean;
    getIsFold?: ((v: boolean) => void) | null;
    isDefaultFold?: boolean;
    unfoldButtonText?: string | JSX.Element | JSX.Element[];
    foldButtonText?: string | JSX.Element | JSX.Element[];
    isShowAllContent?: boolean;
    isMustButton?: boolean;
    isMustNoButton?: boolean;
    lineHeight?: number;
    isRenderShowAllDOM?: boolean;
    /** >>>>>>仅ellipsis配置 */
    ellipsisLineClamp?: number;
    /**
     * 是否使用Js逻辑计算文字开始折叠时显示的文案，可以传字号大小
     * 注意：
     * 1、启用此功能是为了兼容部分浏览器不支持display: -webkit-box;属性的使用（或出现异常）
     * 2、计算出来的文案可能不够完美，可以通过extraOccupiedW调整计算的误差
     * 3、这时只支持传string类型内容
     * 4、此时textEndSlot、buttonBeforeSlot，以及foldButtonText是非string类型（string类型除外）
     * 所额外占用的宽度，都需要通过extraOccupiedW告知组件
     */
    isJsComputed?: boolean;
    fontSize?: number;
    /**
     * 紧跟文字内容尾部的额外内容，可以是icon等任意内容，例如超链接icon，点击跳转到外部网站
     * 文案溢出时显示在...后面，不溢出时在文字尾部
     * 注意：启用isJsComputed时，textEndSlot所占的宽需要通过extraOccupiedW告知才能精确计算
     */
    textEndSlot?: any;
    extraOccupiedW?: number;
    buttonBeforeSlot?: string | JSX.Element | JSX.Element[] | null;
    /** >>>>>>仅shadow配置 */
    shadowInitBoxShowH?: number;
    shadowClassName?: string;
    shadowStyle?: React.CSSProperties;
}
declare function TextOverflowProcessor(props: TextProcessProps): JSX.Element;
declare namespace TextOverflowProcessor {
    var defaultProps: TextProcessProps;
}
declare const _default: import("react").MemoExoticComponent<typeof TextOverflowProcessor>;
export default _default;
